const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const CleanWebpackPlugin = require('clean-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
module.exports = (env, {mode}) => ({
  entry: './index.js',
  module: {
    rules: [
      {test: /\.(png|svg|jpg|gif)$/, use: 'file-loader'},
      {test: /\.(woff|woff2|eot|ttf|otf)$/, use: 'file-loader'},
      {test: /\.(c|sc|sa|le)ss$/, use: mode === 'development' ? 'style-loader' : MiniCssExtractPlugin.loader},
      {test: /\.jsx?$/, include: path.resolve(__dirname, 'src'), use: ['babel-loader']},
      {test: /\.(c|sc|sa|le)ss$/, use: [
        {loader: 'css-loader', options: mode === 'production' ? {
          modules: true,
          localIdentName: 'Pref-[local]-sufX',
          //exportOnlyLocals: true, // throws error!
        } : {}},
      ]},
      {test: /\.(sc|sa)ss$/, use: {loader: 'sass-loader', options: {
          implementation: require('sass'),
      }}},
    ],
  },
  plugins: [
    new HtmlWebpackPlugin({template: 'index.html'}),
    ...(
      mode === 'production' ? [
        new CleanWebpackPlugin(),
        new MiniCssExtractPlugin(),
      ] : []
    ),
  ],
  output: {
    library: 'Widget',
    libraryTarget: 'umd',
    libraryExport: 'default',
    path: path.resolve(__dirname, 'build')
  },
  devtool: mode === 'development' ? 'inline-source-map' : 'source-map',
});
